@@ -6,20 +6,46 @@ WWW::Mechanize - Handy web browsing in a Perl object
 
 =head1 VERSION
 
-Version 1.55_01
+Version 1.66
 
 =cut
 
-our $VERSION = '1.55_01';
+our $VERSION = '1.67_01';
 
 =head1 SYNOPSIS
 
-C<WWW::Mechanize>, or Mech for short, helps you automate interaction with
-a website. It supports performing a sequence of page fetches including
-following links and submitting forms. Each fetched page is parsed and
-its links and forms are extracted. A link or a form can be selected, form
-fields can be filled and the next page can be fetched. Mech also stores
-a history of the URLs you've visited, which can be queried and revisited.
+C<WWW::Mechanize>, or Mech for short, is a Perl module for stateful
+programmatic web browsing, used for automating interaction with
+websites.
+
+Features include:
+
+=over 4
+
+=item * All HTTP methods
+
+=item * High-level hyperlink and HTML form support, without having to parse HTML yourself
+
+=item * SSL support
+
+=item * Automatic cookies
+
+=item * Custom HTTP headers
+
+=item * Automatic handling of redirections
+
+=item * Proxies
+
+=item * HTTP authentication
+
+=back
+
+Mech supports performing a sequence of page fetches including
+following links and submitting forms. Each fetched page is parsed
+and its links and forms are extracted. A link or a form can be
+selected, form fields can be filled and the next page can be fetched.
+Mech also stores a history of the URLs you've visited, which can
+be queried and revisited.
 
     use WWW::Mechanize;
     my $mech = WWW::Mechanize->new();
@@ -103,10 +129,9 @@ use strict;
 use warnings;
 
 use HTTP::Request 1.30;
-use LWP::UserAgent 2.003;
+use LWP::UserAgent 5.827;
 use HTML::Form 1.00;
 use HTML::TokeParser;
-use HTTP::Response::Encoding 0.05;
 
 use base 'LWP::UserAgent';
 
@@ -204,6 +229,10 @@ history.
 
 =back
 
+To support forms, WWW::Mechanize's constructor pushes POST
+on to the agent's C<requests_redirectable> list (see also
+L<LWP::UserAgent>.)
+
 =cut
 
 sub new {
@@ -251,7 +280,7 @@ sub new {
     $self->{proxy} = {} unless defined $self->{proxy};
     push( @{$self->requests_redirectable}, 'POST' );
 
-    $self->_reset_page;
+    $self->_reset_page();
 
     return $self;
 }
@@ -530,7 +559,6 @@ sub status {        my $self = shift; return $self->{status}; }
 sub ct {            my $self = shift; return $self->{ct}; }
 sub content_type {  my $self = shift; return $self->{ct}; }
 sub base {          my $self = shift; return $self->{base}; }
-sub current_form {  my $self = shift; return $self->{form}; }
 sub is_html {       my $self = shift; return defined $self->ct && ($self->ct eq 'text/html'); }
 
 =head2 $mech->title()
@@ -542,12 +570,16 @@ L<HTML::HeadParser>.  Returns undef if the content is not HTML.
 
 sub title {
     my $self = shift;
+
     return unless $self->is_html;
 
-    require HTML::HeadParser;
-    my $p = HTML::HeadParser->new;
-    $p->parse($self->content);
-    return $p->header('Title');
+    if ( not defined $self->{title} ) {
+        require HTML::HeadParser;
+        my $p = HTML::HeadParser->new;
+        $p->parse($self->content);
+        $self->{title} = $p->header('Title');
+    }
+    return $self->{title};
 }
 
 =head1 CONTENT-HANDLING METHODS
@@ -598,7 +630,12 @@ sub content {
         }
 
         if ( my $format = delete $parms{format} ) {
-            $content = $self->_format_content( $format, $content );
+            if ( $format eq 'text' ) {
+                $content = $self->text;
+            }
+            else {
+                $self->die( qq{Unknown "format" parameter "$format"} );
+            }
         }
 
         $self->_check_unhandled_parms( %parms );
@@ -607,32 +644,31 @@ sub content {
     return $content;
 }
 
-sub _format_content {
+=head2 $mech->text()
+
+Returns the text of the current HTML content.  If the content isn't
+HTML, $mech will die.
+
+The text is extracted by parsing the content, and then the extracted
+text is cached, so don't worry about performance of calling this
+repeatedly.
+
+=cut
+
+sub text {
     my $self = shift;
-    my $format = shift;
-    my $content = shift;
 
-    if ( $format eq 'text' ) {
-        return $self->_content_as_text($content);
+    if ( not defined $self->{text} ) {
+        require HTML::TreeBuilder;
+        my $tree = HTML::TreeBuilder->new();
+        $tree->parse( $self->content );
+        $tree->eof();
+        $tree->elementify(); # just for safety
+        $self->{text} = $tree->as_text();
+        $tree->delete;
     }
-    else {
-        $self->die( qq{Unknown "format" parameter "$format"} );
-    }
-}
 
-sub _content_as_text {
-    my $self = shift;
-    my $content = shift;
-
-    require HTML::TreeBuilder;
-    my $tree = HTML::TreeBuilder->new();
-    $tree->parse($content);
-    $tree->eof();
-    $tree->elementify(); # just for safety
-    my $formatted_content = $tree->as_text();
-    $tree->delete;
-
-    return $formatted_content;
+    return $self->{text};
 }
 
 sub _check_unhandled_parms {
@@ -646,7 +682,7 @@ sub _check_unhandled_parms {
 
 =head1 LINK METHODS
 
-=head2 $mech->links
+=head2 $mech->links()
 
 Lists all the links on the current page.  Each link is a
 WWW::Mechanize::Link object. In list context, returns a list of all
@@ -655,9 +691,9 @@ links.  In scalar context, returns an array reference of all links.
 =cut
 
 sub links {
-    my $self = shift ;
+    my $self = shift;
 
-    $self->_extract_links() unless $self->{_extracted_links};
+    $self->_extract_links() unless $self->{links};
 
     return @{$self->{links}} if wantarray;
     return $self->{links};
@@ -706,8 +742,14 @@ sub follow_link {
     }
 
     my $link = $self->find_link(%parms);
-    return $self->get( $link->url ) if $link;
-    $self->die( 'Link not found: ', $link->url ) if $self->{autocheck};
+    if ( $link ) {
+        return $self->get( $link->url );
+    }
+
+    if ( $self->{autocheck} ) {
+        $self->die( 'Link not found' );
+    }
+
     return;
 }
 
@@ -917,6 +959,8 @@ sub _clean_keys {
             }
         }
     } # for keys %parms
+
+    return;
 } # _clean_keys()
 
 
@@ -954,19 +998,15 @@ then the return will be an empty array.
 You may use a regex or a literal string:
 
     # get all textarea controls whose names begin with "customer"
-    my @customer_text_inputs =
-        $mech->find_all_inputs( {
-            type       => 'textarea',
-            name_regex => qr/^customer/,
-        }
+    my @customer_text_inputs = $mech->find_all_inputs(
+        type       => 'textarea',
+        name_regex => qr/^customer/,
     );
 
     # get all text or textarea controls called "customer"
-    my @customer_text_inputs =
-        $mech->find_all_inputs( {
-            type_regex => qr/^(text|textarea)$/,
-            name       => 'customer',
-        }
+    my @customer_text_inputs = $mech->find_all_inputs(
+        type_regex => qr/^(text|textarea)$/,
+        name       => 'customer',
     );
 
 =cut
@@ -1022,9 +1062,9 @@ images.  In scalar context, returns an array reference of all images.
 =cut
 
 sub images {
-    my $self = shift ;
+    my $self = shift;
 
-    $self->_extract_images() unless $self->{_extracted_images};
+    $self->_extract_images() unless $self->{images};
 
     return @{$self->{images}} if wantarray;
     return $self->{images};
@@ -1181,11 +1221,23 @@ context, returns an array reference of all forms.
 =cut
 
 sub forms {
-    my $self = shift ;
+    my $self = shift;
+
+    $self->_extract_forms() unless $self->{forms};
+
     return @{$self->{forms}} if wantarray;
     return $self->{forms};
 }
 
+sub current_form {
+    my $self = shift;
+
+    if ( !$self->{current_form} ) {
+        $self->form_number(1);
+    }
+
+    return $self->{current_form};
+}
 
 =head2 $mech->form_number($number)
 
@@ -1206,14 +1258,13 @@ sub form_number {
     my ($self, $form) = @_;
     # XXX Should we die if no $form is defined? Same question for form_name()
 
-    if ($self->{forms}->[$form-1]) {
-        $self->{form} = $self->{forms}->[$form-1];
-        return $self->{form};
-    }
-    else {
-        $self->warn( "There is no form numbered $form" );
-        return undef;
+    my $forms = $self->forms;
+    if ( $forms->[$form-1] ) {
+        $self->{current_form} = $forms->[$form-1];
+        return $self->{current_form};
     }
+
+    return;
 }
 
 =head2 $mech->form_name( $name )
@@ -1235,15 +1286,16 @@ sub form_name {
 
     my $temp;
     my @matches = grep {defined($temp = $_->attr('name')) and ($temp eq $form) } $self->forms;
-    if ( my $nmatches = @matches ) {
-        $self->warn( "There are $nmatches forms named $form.  The first one was used." )
-            if $nmatches > 1;
-        return $self->{form} = $matches[0];
-    }
-    else {
-        $self->warn( qq{ There is no form named "$form"} );
-        return undef;
+
+    my $nmatches = @matches;
+    if ( $nmatches > 0 ) {
+        if ( $nmatches > 1 ) {
+            $self->warn( "There are $nmatches forms named $form.  The first one was used." )
+        }
+        return $self->{current_form} = $matches[0];
     }
+
+    return;
 }
 
 =head2 $mech->form_id( $name )
@@ -1267,7 +1319,7 @@ sub form_id {
     if ( @matches ) {
         $self->warn( 'There are ', scalar @matches, " forms with ID $formid.  The first one was used." )
             if @matches > 1;
-        return $self->{form} = $matches[0];
+        return $self->{current_form} = $matches[0];
     }
     else {
         $self->warn( qq{ There is no form with ID "$formid"} );
@@ -1304,10 +1356,12 @@ sub form_with_fields {
         push @matches, $form;
     }
 
-    if ( my $nmatches = @matches ) {
-        $self->warn( "There are $nmatches forms with the named fields.  The first one was used." )
-            if $nmatches > 1;
-        return $self->{form} = $matches[0];
+    my $nmatches = @matches;
+    if ( $nmatches > 0 ) {
+        if ( $nmatches > 1 ) {
+            $self->warn( "There are $nmatches forms with the named fields.  The first one was used." )
+        }
+        return $self->{current_form} = $matches[0];
     }
     else {
         $self->warn( qq{There is no form with the requested fields} );
@@ -1337,7 +1391,7 @@ sub field {
     my ($self, $name, $value, $number) = @_;
     $number ||= 1;
 
-    my $form = $self->{form};
+    my $form = $self->current_form();
     if ($number > 1) {
         $form->find_input($name, undef, $number)->value($value);
     }
@@ -1356,23 +1410,28 @@ sub field {
 =head2 $mech->select($name, \@values)
 
 Given the name of a C<select> field, set its value to the value
-specified.  If the field is not E<lt>select multipleE<gt> and the
+specified.  If the field is not C<< <select multiple> >> and the
 C<$value> is an array, only the B<first> value will be set.  [Note:
 the documentation previously claimed that only the last value would
 be set, but this was incorrect.]  Passing C<$value> as a hash with
 an C<n> key selects an item by number (e.g.
-C<< {n => 3} >> or C<{ {n => [2,4]} >>).
+C<< {n => 3} >> or C<< {n => [2,4]} >>).
 The numbering starts at 1.  This applies to the current form.
 
-Returns 1 on successfully setting the value. On failure, returns
-undef and calls C<< $self>warn() >> with an error message.
+If you have a field with C<< <select multiple> >> and you pass a single
+C<$value>, then C<$value> will be added to the list of fields selected,
+without clearing the others.  However, if you pass an array reference,
+then all previously selected values will be cleared.
+
+Returns true on successfully setting the value. On failure, returns
+false and calls C<< $self>warn() >> with an error message.
 
 =cut
 
 sub select {
     my ($self, $name, $value) = @_;
 
-    my $form = $self->{form};
+    my $form = $self->current_form();
 
     my $input = $form->find_input($name);
     if (!$input) {
@@ -1451,7 +1510,7 @@ of the duplicate field to set, use a value which is an anonymous array
 which has the field value and its number as the 2 elements.
 
         # set the second foo field
-        $mech->set_fields( $name => [ 'foo', 2 ] ) ;
+        $mech->set_fields( $name => [ 'foo', 2 ] );
 
 The fields are numbered from 1.
 
@@ -1484,7 +1543,7 @@ password, you do not have to fetch the form and inspect the source (or
 use the F<mech-dump> utility, installed with WWW::Mechanize) to see
 what the field names are; you can just say
 
-    $mech->set_visible( $username, $password ) ;
+    $mech->set_visible( $username, $password );
 
 and the first and second fields will be set accordingly.  The method
 is called set_I<visible> because it acts only on visible fields;
@@ -1499,11 +1558,11 @@ you to specify the I<type> of input field you want to set and is
 denoted with an arrayref containing two elements.  So you could
 specify the first radio button with
 
-    $mech->set_visible( [ radio => 'KCRW' ] ) ;
+    $mech->set_visible( [ radio => 'KCRW' ] );
 
 Field values and specifiers can be intermixed, hence
 
-    $mech->set_visible( 'fred', 'secret', [ option => 'Checking' ] ) ;
+    $mech->set_visible( 'fred', 'secret', [ option => 'Checking' ] );
 
 would set the first two fields to "fred" and "secret", and the I<next>
 C<OPTION> menu field to "Checking".
@@ -1615,7 +1674,7 @@ sub value {
     my $name = shift;
     my $number = shift || 1;
 
-    my $form = $self->{form};
+    my $form = $self->current_form;
     if ( $number > 1 ) {
         return $form->find_input( $name, undef, $number )->value();
     }
@@ -1641,7 +1700,7 @@ Returns an L<HTTP::Response> object.
 sub click {
     my ($self, $button, $x, $y) = @_;
     for ($x, $y) { $_ = 1 unless defined; }
-    my $request = $self->{form}->click($button, $x, $y);
+    my $request = $self->current_form->click($button, $x, $y);
     return $self->request( $request );
 }
 
@@ -1654,19 +1713,19 @@ the keys.
 
 =over 4
 
-=item * name => name
+=item * C<< name => name >>
 
 Clicks the button named I<name> in the current form.
 
-=item * number => n
+=item * C<< number => n >>
 
 Clicks the I<n>th button in the current form. Numbering starts at 1.
 
-=item * value => value
+=item * C<< value => value >>
 
 Clicks the button with the value I<value> in the current form.
 
-=item * input => $inputobject
+=item * C<< input => $inputobject >>
 
 Clicks on the button referenced by $inputobject, an instance of
 L<HTML::Form::SubmitInput> obtained e.g. from
@@ -1675,9 +1734,9 @@ L<HTML::Form::SubmitInput> obtained e.g. from
 
 $inputobject must belong to the current form.
 
-=item * x => x
+=item * C<< x => x >>
 
-=item * y => y
+=item * C<< y => y >>
 
 These arguments (optional) allow you to specify the (x,y) coordinates
 of the click.
@@ -1700,7 +1759,8 @@ sub click_button {
         $_ = 1 unless defined;
     }
 
-    my $form = $self->{form};
+    my $form = $self->current_form or $self->die( 'click_button: No form has been selected' );
+
     my $request;
     if ( $args{name} ) {
         $request = $form->click( $args{name}, $args{x}, $args{y} );
@@ -1741,7 +1801,7 @@ longer so.
 sub submit {
     my $self = shift;
 
-    my $request = $self->{form}->make_request;
+    my $request = $self->current_form->make_request;
     return $self->request( $request );
 }
 
@@ -1754,11 +1814,11 @@ are a list of key/value pairs, all of which are optional.
 
 =over 4
 
-=item * fields => \%fields
+=item * C<< fields => \%fields >>
 
 Specifies the fields to be filled in the current form.
 
-=item * with_fields => \%fields
+=item * C<< with_fields => \%fields >>
 
 Probably all you need for the common case. It combines a smart form selector
 and data setting in one operation. It selects the first form that contains all
@@ -1769,24 +1829,24 @@ the name or number of the form to do this.
 
 If you choose this, the form_number, form_name, form_id and fields options will be ignored.
 
-=item * form_number => n
+=item * C<< form_number => n >>
 
 Selects the I<n>th form (calls C<L</form_number()>>).  If this parm is not
 specified, the currently-selected form is used.
 
-=item * form_name => name
+=item * C<< form_name => name >>
 
 Selects the form named I<name> (calls C<L</form_name()>>)
 
-=item * form_id => ID
+=item * C<< form_id => ID >>
 
 Selects the form with ID I<ID> (calls C<L</form_id()>>)
 
-=item * button => button
+=item * C<< button => button >>
 
 Clicks on button I<button> (calls C<L</click()>>)
 
-=item * x => x, y => y
+=item * C<< x => x, y => y >>
 
 Sets the x or y values for C<L</click()>>
 
@@ -1796,12 +1856,17 @@ If no form is selected, the first form found is used.
 
 If I<button> is not passed, then the C<L</submit()>> method is used instead.
 
+If you want to submit a file and get its content from a scalar rather
+than a file in the filesystem, you can use:
+
+    $mech->submit_form(with_fields => { logfile => [ [ undef, 'whatever', Content => $content ], 1 ] } );
+
 Returns an L<HTTP::Response> object.
 
 =cut
 
 sub submit_form {
-    my( $self, %args ) = @_ ;
+    my( $self, %args ) = @_;
 
     for ( keys %args ) {
         if ( !/^(form_(number|name|fields|id)|(with_)?fields|button|x|y)$/ ) {
@@ -1978,6 +2043,28 @@ sub save_content {
     return;
 }
 
+
+=head2 $mech->dump_headers( [$fh] )
+
+Prints a dump of the HTTP response headers for the most recent
+response.  If I<$fh> is not specified or is undef, it dumps to
+STDOUT.
+
+Unlike the rest of the dump_* methods, you cannot specify a filehandle
+to print to.
+
+=cut
+
+sub dump_headers {
+    my $self = shift;
+    my $fh   = shift || \*STDOUT;
+
+    print {$fh} $self->response->headers_as_string;
+
+    return;
+}
+
+
 =head2 $mech->dump_links( [[$fh], $absolute] )
 
 Prints a dump of the links on the current page to I<$fh>.  If I<$fh>
@@ -2039,23 +2126,19 @@ sub dump_forms {
     return;
 }
 
-=head2 $mech->dump_all( [[$fh], $absolute] )
+=head2 $mech->dump_text( [$fh] )
 
-Prints a dump of all links, images and forms on the current page to
-I<$fh>.  If I<$fh> is not specified or is undef, it dumps to STDOUT.
-
-If I<$absolute> is true, links displayed are absolute, not relative.
+Prints a dump of the text on the current page to I<$fh>.  If I<$fh>
+is not specified or is undef, it dumps to STDOUT.
 
 =cut
 
-sub dump_all {
+sub dump_text {
     my $self = shift;
     my $fh = shift || \*STDOUT;
     my $absolute = shift;
 
-    $self->dump_links( $fh, $absolute );
-    $self->dump_images( $fh, $absolute );
-    $self->dump_forms( $fh, $absolute );
+    print {$fh} $self->text, "\n";
 
     return;
 }
@@ -2086,6 +2169,9 @@ An overloaded version of C<redirect_ok()> in L<LWP::UserAgent>.
 This method is used to determine whether a redirection in the request
 should be followed.
 
+Note that WWW::Mechanize's constructor pushes POST on to the agent's
+C<requests_redirectable> list.
+
 =cut
 
 sub redirect_ok {
@@ -2124,9 +2210,7 @@ sub request {
         $self->_push_page_stack();
     }
 
-    $self->_update_page($request, $self->_make_request( $request, @_ ));
-
-    # XXX This should definitively return something.
+    return $self->_update_page($request, $self->_make_request( $request, @_ ));
 }
 
 =head2 $mech->update_html( $html )
@@ -2174,18 +2258,6 @@ sub update_html {
     $self->{ct} = 'text/html';
     $self->{content} = $html;
 
-    $self->{forms} = [ HTML::Form->parse($html, $self->base) ];
-    for my $form (@{ $self->{forms} }) {
-        for my $input ($form->inputs) {
-             if ($input->type eq 'file') {
-                 $input->value( undef );
-             }
-        }
-    }
-    $self->{form}  = $self->{forms}->[0];
-    $self->{_extracted_links} = 0;
-    $self->{_extracted_images} = 0;
-
     return;
 }
 
@@ -2238,6 +2310,44 @@ sub clear_credentials {
     delete @$self{qw( __username __password )};
 }
 
+=head1 INHERITED UNCHANGED LWP::UserAgent METHODS
+
+As a sublass of L<LWP::UserAgent>, WWW::Mechanize inherits all of
+L<LWP::UserAgent>'s methods.  Many of which are overridden or
+extended. The following methods are inherited unchanged. View the
+L<LWP::UserAgent> documentation for their implementation descriptions.
+
+This is not meant to be an inclusive list.  LWP::UA may have added
+others.
+
+=head2 $mech->head()
+
+Inherited from L<LWP::UserAgent>.
+
+=head2 $mech->post()
+
+Inherited from L<LWP::UserAgent>.
+
+=head2 $mech->mirror()
+
+Inherited from L<LWP::UserAgent>.
+
+=head2 $mech->simple_request()
+
+Inherited from L<LWP::UserAgent>.
+
+=head2 $mech->is_protocol_supported()
+
+Inherited from L<LWP::UserAgent>.
+
+=head2 $mech->prepare_request()
+
+Inherited from L<LWP::UserAgent>.
+
+=head2 $mech->progress()
+
+Inherited from L<LWP::UserAgent>.
+
 =head1 INTERNAL-ONLY METHODS
 
 These methods are only used internally.  You probably don't need to
@@ -2308,7 +2418,7 @@ sub _taintedness {
     return $_taintbrush if _is_tainted( $_taintbrush );
 
     # Let's try again. Maybe somebody cleaned those.
-    $_taintbrush = substr(join("", @ARGV, %ENV), 0, 0);
+    $_taintbrush = substr(join('', grep { defined } @ARGV, %ENV), 0, 0);
     return $_taintbrush if _is_tainted( $_taintbrush );
 
     # If those don't work, go try to open some file from some unsafe
@@ -2398,13 +2508,12 @@ Resets the internal fields that track page parsed stuff.
 sub _reset_page {
     my $self = shift;
 
-    $self->{_extracted_links}  = 0;
-    $self->{_extracted_images} = 0;
-    $self->{links}             = [];
-    $self->{images}            = [];
-    $self->{forms}             = [];
-
-    delete $self->{form};
+    $self->{links}        = undef;
+    $self->{images}       = undef;
+    $self->{forms}        = undef;
+    $self->{current_form} = undef;
+    $self->{title}        = undef;
+    $self->{text}         = undef;
 
     return;
 }
@@ -2438,8 +2547,6 @@ sub _extract_links {
         } # while
     }
 
-    $self->{_extracted_links} = 1;
-
     return;
 }
 
@@ -2462,8 +2569,6 @@ sub _extract_images {
         } # while
     }
 
-    $self->{_extracted_images} = 1;
-
     return;
 }
 
@@ -2548,6 +2653,23 @@ sub _link_from_token {
         });
 } # _link_from_token
 
+
+sub _extract_forms {
+    my $self = shift;
+
+    my @forms = HTML::Form->parse( $self->content, $self->base );
+    $self->{forms} = \@forms;
+    for my $form ( @forms ) {
+        for my $input ($form->inputs) {
+             if ($input->type eq 'file') {
+                 $input->value( undef );
+             }
+        }
+    }
+
+    return;
+}
+
 =head2 $mech->_push_page_stack()
 
 The agent keeps a stack of visited pages, which it can pop when it needs
@@ -2629,17 +2751,13 @@ sub _die {
 
 __END__
 
-=head1 REQUESTS & BUGS
+=head1 WWW::MECHANIZE'S GIT REPOSITORY
 
-The bug queue for WWW::Mechanize and Test::WWW::Mechanize is at
-L<http://code.google.com/p/www-mechanize/issues/list>.  Please do
-not add any tickets to the old queue at L<http://rt.cpan.org/>.
+WWW::Mechanize is hosted at GitHub, though the bug tracker still
+lives at Google Code.
 
-=head1 WWW::MECHANIZE'S SUBVERSION REPOSITORY
-
-Mech and Test::WWW::Mechanize are both hosted at Google Code:
-http://code.google.com/p/www-mechanize/.  The Subversion repository
-is at http://www-mechanize.googlecode.com/svn/wm/.
+Repository: https://github.com/bestpractical/www-mechanize/.  
+Bugs: http://code.google.com/p/www-mechanize/issues
 
 =head1 OTHER DOCUMENTATION
 
@@ -2794,6 +2912,13 @@ Just like Mech, but using Microsoft Internet Explorer to do the work.
 Thanks to the numerous people who have helped out on WWW::Mechanize in
 one way or another, including
 Kirrily Robert for the original C<WWW::Automate>,
+Lyle Hopkins,
+Damien Clark,
+Ansgar Burchardt,
+Gisle Aas,
+Jeremy Ary,
+Hilary Holz,
+Rafael Kitover,
 Norbert Buchmuller,
 Dave Page,
 David Sainty,
@@ -2841,7 +2966,7 @@ and the late great Iain Truskett.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2009 Andy Lester. All rights reserved. This program is
+Copyright (c) 2005-2010 Andy Lester. All rights reserved. This program is
 free software; you can redistribute it and/or modify it under the same
 terms as Perl itself.
 
